@@ -10,9 +10,7 @@ class GraphLine:
         self.data = []
 
     def get_line_data(self):
-        data_str = "\t{l_name}\t{l_type}\t{l_color}\t".format(
-            l_name=self.name, l_type=self.line_type.value, l_color=self.color.value
-        )
+        data_str = f"\t{self.name}\t{self.line_type.value}\t{self.color.value}\t"
         data_str += "\t".join(map(str, self.data))
         data_str += "\n"
         return data_str
