@@ -10,7 +10,7 @@ class Selector(Control):
         self._cfg["selection"] = self.selection_list
 
     def get_state(self):
-        _state_str = self._state_str + "{}\t".format(self.position)
+        _state_str = self._state_str + f"{self.position}\t"
         _state_str += "\t".join(map(str, self.selection_list))
         _state_str += "\n"
         return _state_str
@@ -21,7 +21,7 @@ class Selector(Control):
     def set_selected(self, selected_text):
         if selected_text in self.selection_list:
             self._position = self.selection_list.index(selected_text)
-            slctr_str = self._state_str + "{}\t".format(self._position)
+            slctr_str = self._state_str + f"{self._position}\t"
             slctr_str += "\t".join(map(str, self.selection_list))
             slctr_str += "\n"
             self.state_str = slctr_str
@@ -35,6 +35,6 @@ class Selector(Control):
         try:
             _ = self.selection_list[val]
             self._position = val
-            self.state_str = self._state_str + "{}\n".format(self._position)
+            self.state_str = self._state_str + f"{self._position}\n"
         except IndexError:
             pass
